--[[
Bison - a framework for free positioning of buffs.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to:
	
Free Software Foundation, I.,
51 Franklin Street, Fifth Floor,
Boston, MA  02110-1301, USA.
--]]

local MAJOR = 'hijack'

local Addon    = LibStub( 'AceAddon-3.0'):GetAddon( 'Bison')
local L        = LibStub( 'AceLocale-3.0'):GetLocale( 'Bison')
local AceGUI   = LibStub( 'AceGUI-3.0')

local MAX_BUTTON  = 40
local FILTER      = 'HELPFUL'

local Module = Addon:NewBarModule( MAJOR, 'AceHook-3.0')
Module.filter  = FILTER
Module.color   = { r=0.2, g=0.8, b=0.2 }
Module.proName = 'hijack'

local args = {
	option = { 
		type = 'group', order = 10, name = L.OptionName, inline = true, 
		args = {
			show     = { type = 'toggle', order = 10, name = L.ShowName,     desc = L.ShowDesc },
			join     = { type = 'toggle', order = 15, name = L.JoinName,     desc = L.JoinDesc,     set = 'SetJoin',     get = 'GetJoin' },
			sort     = { type = 'select', order = 40, name = L.SortName,     desc = L.SortDesc,     set = 'SetSortType', get = 'GetSortType', values = 'GetSortDesc' },
		} 
	},
	layout = { 
		type = 'group', order = 20, name = L.BarName, inline = true, 
		args = {
			horizontal = { type = 'toggle', order = 10, name = L.HorizontalName, desc = L.HorizontalDesc, width = 'full' },
			number     = { type = 'range',  order = 30, name = L.NumberName,     desc = L.NumberDesc,   set = 'SetNumber',   min = 1,    max = MAX_BUTTON, step = 1 },
			scale      = { type = 'range',  order = 40, name = L.ScaleName,      desc = L.ScaleDesc,    set = 'SetScale',    min = 0.01, max = 2,          step = 0.01, isPercent = true },
			cols       = { type = 'range',  order = 50, name = L.ColsName,       desc = L.ColsDesc,     set = 'SetCols',     min = 1,    max = MAX_BUTTON, step = 1 },
			xPadding   = { type = 'range',  order = 60, name = L.XPaddingName,   desc = L.XPaddingDesc, set = 'SetXPadding', min = -20,  max = 20,         step = 1 },
			rows       = { type = 'range',  order = 70, name = L.RowsName,       desc = L.RowsDesc,     set = 'SetRows',     min = 1,    max = MAX_BUTTON, step = 1 },
			yPadding   = { type = 'range',  order = 80, name = L.YPaddingName,   desc = L.YPaddingDesc, set = 'SetYPadding', min = -50,  max = 50,         step = 1 },
		} 
	}
}

local blizzOptions = {
	type = 'group', order = 70, name = L.DescSecure, handler = Module, get = 'GetProperty', set = 'SetProperty', args = args
}

local dialogOptions = {
	type = 'group', order = 20, name = L.BarHijack, handler = Module, get = 'GetProperty', set = 'SetProperty', args = args,
	plugins = {
		p1 = { 
			descr = { type = 'description', order = 5, name = L.DescSecure, fontSize = 'large' }
		}
	}
}

--[[---------------------------------------------------------------------------------
Main
------------------------------------------------------------------------------------]]
function Module:OnModuleInitialize()
	self:RegisterOptions( blizzOptions, L.BarHijack)
	self:CloneAura( 'buff')
--	self:RawHook( BuffFrame, 'SetPoint', 'UpdateSetPoint', true)
	self:RawHook( BuffFrame_UpdateAllBuffAnchors, 'UpdateAllBuffAnchors', true)
	self:RawHook( AuraButton_UpdateDuration, 'UpdateDuration', true)
end

function Module:GetOptionTable()
	return dialogOptions
end

function Module:CreateButton()
	local btn = self:CreateNormButton( 'BisonHijack')
	return btn
end

function Module:UpdateValues()
end

function Module:UpdateSetPoint()
	BuffFrame:SetAllPoints( self.group.frame)
end

function Module:UpdateAllBuffAnchors( self)
	for i,child in pairs( self.group.children) do
		if i <= BUFF_ACTUAL_DISPLAY then
			child:SetBuff( _G['BuffButton'..i])
		else
			child:SetBuff( nil)
		end
	end
	self.group:DoLayout()
	TemporaryEnchantFrame_OnUpdate()
end

function Module:UpdateDuration( self, button, timeLeft)
	if SHOW_BUFF_DURATIONS == "1" and timeLeft then
		local child = _G[button:GetName()..'Duration']
		child:SetText( Addon.DurationString( timeLeft, self.profile.timer))
	end
end
